package com.tencent.qcloud.ilivedemo.login.view;

import android.app.Activity;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.TextView;

import com.tencent.TIMManager;
import com.tencent.av.sdk.AVContext;
import com.tencent.ilivesdk.ILiveSDK;
import com.tencent.qcloud.ilivedemo.integrationLogin.R;
import com.tencent.qcloud.ilivedemo.login.present.LoginHelper;
import com.tencent.qcloud.ilivedemo.login.viewinterface.ILoginView;


public class MainActivity extends Activity implements View.OnClickListener, ILoginView {

    Spinner mAccountSpiner;
    TextView mLoginState;
    Button mLoginBtn;
    private LoginHelper mLoginHelper;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mLoginHelper = new LoginHelper(this);
        initView();
    }


    /**
     * 初始化UI
     */
    private void initView() {
        mAccountSpiner = findViewById(R.id.account_spinner);
        mLoginBtn = findViewById(R.id.login_btn);
        mLoginBtn.setOnClickListener(this);
        mLoginState = findViewById(R.id.login_state);
        initSDKInfo();
    }


    /**
     * 获取sdk信息
     */
    public void initSDKInfo() {
        String version = " iLiveSDK: " + ILiveSDK.getInstance().getVersion() + "\n IMSDK:" +
                TIMManager.getInstance().getVersion() + "\n AVSDK:" +
                AVContext.sdkVersion;
        TextView tvVersion = findViewById(R.id.tv_version);
        tvVersion.setText(version);
    }


    @Override
    public void onLoginSDKSuccess() {
        updateLoginState(true);
        System.out.println("登录成功");
    }


    @Override
    public void onLoginSDKFailed(int errCode, String errMsg) {
        System.out.println("登录失败。错误码：" + errCode + "::::" + errMsg);
    }

    @Override
    public void onLogoutSDKSuccess() {
        updateLoginState(false);
        System.out.println("注销成功");
    }

    @Override
    public void onLogoutSDKFailed(int errCode, String errMsg) {
        System.out.println("注销失败：" + errCode + "::::" + errMsg);
    }

    /**
     * 更新UI的登录状态
     *
     * @param state
     */
    public void updateLoginState(boolean state) {
        String textLable = state ? "已登录" : "未登陆";
        int color = state ? Color.GREEN : Color.RED;
        mLoginState.setText(textLable);
        mLoginState.setTextColor(color);
        String buttonLabel = state ? "注销" : "登录";
        mLoginBtn.setText(buttonLabel);
    }


    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.login_btn:
                mLoginHelper.login(mAccountSpiner.getSelectedItem().toString());
                break;
        }
    }

}
